[openib-general] [PATCH][TRIVIAL] OpenSM: Change QoS syntax for CA ports

Hal Rosenstock halr at voltaire.com
Mon Sep 11 06:23:37 PDT 2006


OpenSM: Change QoS syntax for CA ports

Change names from hca_ to ca_ to make it clearer that these are for both
HCAs and TCAs.

Signed-off-by: Hal Rosenstock <halr at voltaire.com>

Index: doc/qos-config.txt
===================================================================
--- doc/qos-config.txt	(revision 9347)
+++ doc/qos-config.txt	(working copy)
@@ -28,11 +28,11 @@ values may be stored in OpenSM config fi
 
 In addition to the above, we may define separate QoS configuration
 parameters sets for various target types. As targets, we currently support
-HCA, routers, switch external ports, and switch's enhanced port 0. The
+CAs, routers, switch external ports, and switch's enhanced port 0. The
 names of such specialized parameters are prefixed by "qos_<type>_"
 string. Here is a full list of the currently supported sets:
 
-  qos_hca_ - QoS configuration parameters set for HCAs.
+  qos_ca_  - QoS configuration parameters set for CAs.
   qos_rtr_ - parameters set for routers.
   qos_sw0_ - parameters set for switches' port 0.
   qos_swe_ - parameters set for switches' external ports.
@@ -40,5 +40,5 @@ string. Here is a full list of the curre
 Examples:
 
   qos_sw0_max_vls=2
-  qos_hca_sl2vl=0,1,2,3,5,5,5,12,12,0,
+  qos_ca_sl2vl=0,1,2,3,5,5,5,12,12,0,
   qos_swe_high_limit=0
Index: man/opensm.8
===================================================================
--- man/opensm.8	(revision 9347)
+++ man/opensm.8	(working copy)
@@ -1,4 +1,4 @@
-.TH OPENSM 8 "Setpember 6, 2006" "OpenIB" "OpenIB Management"
+.TH OPENSM 8 "Setpember 11, 2006" "OpenIB" "OpenIB Management"
 
 .SH NAME
 opensm \- InfiniBand subnet manager and administration (SM/SA) 
@@ -365,18 +365,18 @@ values may be stored in OpenSM config fi
 
 In addition to the above, we may define separate QoS configuration
 parameters sets for various target types. As targets, we currently support
-HCA, routers, switch external ports, and switch's enhanced port 0. The
+CAs, routers, switch external ports, and switch's enhanced port 0. The
 names of such specialized parameters are prefixed by "qos_<type>_"
 string. Here is a full list of the currently supported sets:
 
- qos_hca_ - QoS configuration parameters set for HCAs.
+ qos_ca_  - QoS configuration parameters set for CAs.
  qos_rtr_ - parameters set for routers.
  qos_sw0_ - parameters set for switches' port 0.
  qos_swe_ - parameters set for switches' external ports.
 
 Examples:
  qos_sw0_max_vls=2
- qos_hca_sl2vl=0,1,2,3,5,5,5,12,12,0,
+ qos_ca_sl2vl=0,1,2,3,5,5,5,12,12,0,
  qos_swe_high_limit=0
 
 .SH ROUTING
Index: opensm/osm_subnet.c
===================================================================
--- opensm/osm_subnet.c	(revision 9351)
+++ opensm/osm_subnet.c	(working copy)
@@ -495,7 +495,7 @@ osm_subn_set_default_opt(
   p_opt->updn_guid_file = NULL;
   p_opt->exit_on_fatal = TRUE;
   subn_set_default_qos_options(&p_opt->qos_options);
-  subn_set_default_qos_options(&p_opt->qos_hca_options);
+  subn_set_default_qos_options(&p_opt->qos_ca_options);
   subn_set_default_qos_options(&p_opt->qos_sw0_options);
   subn_set_default_qos_options(&p_opt->qos_swe_options);
   subn_set_default_qos_options(&p_opt->qos_rtr_options);
@@ -737,8 +737,8 @@ osm_subn_rescan_conf_file(
       subn_parse_qos_options("qos",
         p_key, p_val, &p_opts->qos_options);
 
-      subn_parse_qos_options("qos_hca",
-        p_key, p_val, &p_opts->qos_hca_options);
+      subn_parse_qos_options("qos_ca",
+        p_key, p_val, &p_opts->qos_ca_options);
 
       subn_parse_qos_options("qos_sw0",
         p_key, p_val, &p_opts->qos_sw0_options);
@@ -967,8 +967,8 @@ osm_subn_parse_conf_file(
       subn_parse_qos_options("qos",
         p_key, p_val, &p_opts->qos_options);
 
-      subn_parse_qos_options("qos_hca",
-        p_key, p_val, &p_opts->qos_hca_options);
+      subn_parse_qos_options("qos_ca",
+        p_key, p_val, &p_opts->qos_ca_options);
 
       subn_parse_qos_options("qos_sw0",
         p_key, p_val, &p_opts->qos_sw0_options);
@@ -1211,7 +1211,7 @@ osm_subn_write_conf_file(
     "QoS default options", "qos", &p_opts->qos_options);
   fprintf(opts_file, "\n");
   subn_dump_qos_options(opts_file,
-    "QoS HCA options", "qos_hca", &p_opts->qos_hca_options);
+    "QoS CA options", "qos_ca", &p_opts->qos_ca_options);
   fprintf(opts_file, "\n");
   subn_dump_qos_options(opts_file,
     "QoS Switch Port 0 options", "qos_sw0", &p_opts->qos_sw0_options);
Index: opensm/osm_qos.c
===================================================================
--- opensm/osm_qos.c	(revision 9347)
+++ opensm/osm_qos.c	(working copy)
@@ -318,7 +318,7 @@ static ib_api_status_t qos_physp_setup(o
 
 osm_signal_t osm_qos_setup(osm_opensm_t * p_osm)
 {
-	struct qos_config hca_config, sw0_config, swe_config, rtr_config;
+	struct qos_config ca_config, sw0_config, swe_config, rtr_config;
 	struct qos_config *cfg;
 	osm_switch_t *p_sw;
 	ib_switch_info_t *p_si;
@@ -336,7 +336,7 @@ osm_signal_t osm_qos_setup(osm_opensm_t 
 
 	OSM_LOG_ENTER(&p_osm->log, osm_qos_setup);
 
-	qos_build_config(&hca_config, &p_osm->subn.opt.qos_hca_options,
+	qos_build_config(&ca_config, &p_osm->subn.opt.qos_ca_options,
 			 &p_osm->subn.opt.qos_options);
 	qos_build_config(&sw0_config, &p_osm->subn.opt.qos_sw0_options,
 			 &p_osm->subn.opt.qos_options);
@@ -376,7 +376,7 @@ osm_signal_t osm_qos_setup(osm_opensm_t 
 		else if (node_type == IB_NODE_TYPE_ROUTER)
 			cfg = &rtr_config;
 		else
-			cfg = &hca_config;
+			cfg = &ca_config;
 
 		p_physp = osm_port_get_default_phys_ptr(p_port);
 		if (!osm_physp_is_valid(p_physp))







More information about the general mailing list
Index: include/opensm/osm_subnet.h
===================================================================
--- include/opensm/osm_subnet.h	(revision 9351)
+++ include/opensm/osm_subnet.h	(working copy)
@@ -282,7 +282,7 @@ typedef struct _osm_subn_opt
   boolean_t                exit_on_fatal;
   boolean_t                honor_guid2lid_file;
   osm_qos_options_t        qos_options;
-  osm_qos_options_t        qos_hca_options;
+  osm_qos_options_t        qos_ca_options;
   osm_qos_options_t        qos_sw0_options;
   osm_qos_options_t        qos_swe_options;
   osm_qos_options_t        qos_rtr_options;
@@ -457,8 +457,8 @@ typedef struct _osm_subn_opt
 *	qos_options
 *		Default set of QoS options
 *
 *	qos_hca_options
 *		QoS options for HCA ports
 *
 *	qos_sw0_options
 *		QoS options for switches' port 0
@@ -457,8 +457,8 @@ typedef struct _osm_subn_opt
 *		Default set of QoS options
 *
-*	qos_hca_options
-*		QoS options for HCA ports
+*	qos_ca_options
+*		QoS options for CA ports
 *
 *	qos_sw0_options